@@ -189,6 +189,7 @@ C   thnew    non-adaptive estimates    (output)
 C   kern     specifies the location kernel
 C   wght     scaling factor for second and third dimension (larger values shrink)
 C
+      use omp_lib
       implicit none
       external kldistd,lkern
       double precision kldistd,lkern
@@ -197,8 +198,8 @@ C
       integer ih,ih1,ii,i1,i2,j1,j2,k,n,thrednr,
      1        jind,jind2,jwind2,dlw,clw,jw1,jw2
       double precision swj,swj0,z1,z2,wj,hakt2
-!$      integer omp_get_thread_num
-!$      external omp_get_thread_num
+C!$      integer omp_get_thread_num
+C!$      external omp_get_thread_num
       hakt2=hakt*hakt
       ih=FLOOR(hakt)
       dlw=2*ih+1
